@@ -5,7 +5,7 @@ from aiocache import cached
 from nonebot.log import logger
 
 
-data_path = Path() / 'data' / 'petpet'
+data_path = Path() / "data" / "petpet"
 
 
 class DownloadError(Exception):
@@ -25,7 +25,7 @@ async def download_url(url: str) -> bytes:
                     continue
                 return resp.content
             except Exception as e:
-                logger.warning(f'Error downloading {url}, retry {i}/3: {e}')
+                logger.warning(f"Error downloading {url}, retry {i}/3: {e}")
     raise DownloadError
 
 
@@ -33,10 +33,10 @@ async def get_resource(path: str, name: str) -> bytes:
     file_path = data_path / path / name
     if not file_path.exists():
         file_path.parent.mkdir(parents=True, exist_ok=True)
-        url = f'https://cdn.jsdelivr.net/gh/MeetWq/nonebot-plugin-petpet@master/resources/{path}/{name}'
+        url = f"https://cdn.jsdelivr.net/gh/MeetWq/nonebot-plugin-petpet@master/resources/{path}/{name}"
         data = await download_url(url)
         if data:
-            with file_path.open('wb') as f:
+            with file_path.open("wb") as f:
                 f.write(data)
     if not file_path.exists():
         raise ResourceError
@@ -45,19 +45,19 @@ async def get_resource(path: str, name: str) -> bytes:
 
 @cached(ttl=600)
 async def get_image(name: str) -> bytes:
-    return await get_resource('images', name)
+    return await get_resource("images", name)
 
 
 @cached(ttl=600)
 async def get_font(name: str) -> bytes:
-    return await get_resource('fonts', name)
+    return await get_resource("fonts", name)
 
 
 @cached(ttl=60)
 async def download_avatar(user_id: str) -> bytes:
     url = f"http://q1.qlogo.cn/g?b=qq&nk={user_id}&s=640"
     data = await download_url(url)
-    if not data or hashlib.md5(data).hexdigest() == 'acef72340ac0e914090bd35799f5594e':
+    if not data or hashlib.md5(data).hexdigest() == "acef72340ac0e914090bd35799f5594e":
         url = f"http://q1.qlogo.cn/g?b=qq&nk={user_id}&s=100"
         data = await download_url(url)
         if not data:
