@@ -8,7 +8,7 @@ from PIL import Image, ImageDraw, ImageFilter, ImageFont
 
 from .download import get_font, get_image
 
-DEFAULT_FONT = 'SourceHanSansSC-Regular.otf'
+DEFAULT_FONT = "SourceHanSansSC-Regular.otf"
 
 
 def resize(img: IMG, size: Tuple[int, int]) -> IMG:
@@ -20,7 +20,7 @@ def rotate(img: IMG, angle: int, expand: bool = True) -> IMG:
 
 
 def circle(img: IMG) -> IMG:
-    mask = Image.new('L', img.size, 0)
+    mask = Image.new("L", img.size, 0)
     draw = ImageDraw.Draw(mask)
     draw.ellipse((1, 1, img.size[0] - 2, img.size[1] - 2), fill=255)
     mask = mask.filter(ImageFilter.GaussianBlur(0))
@@ -31,18 +31,22 @@ def circle(img: IMG) -> IMG:
 def square(img: IMG) -> IMG:
     width, height = img.size
     length = min(width, height)
-    return img.crop(((width - length) / 2, (height - length) / 2,
-                     (width + length) / 2, (height + length) / 2))
+    return img.crop(
+        (
+            int((width - length) / 2),
+            int((height - length) / 2),
+            int((width + length) / 2),
+            int((height + length) / 2),
+        )
+    )
 
 
 def perspective(img: IMG, points: List[Tuple[float, float]]):
     def find_coeffs(pa: List[Tuple[float, float]], pb: List[Tuple[float, float]]):
         matrix = []
         for p1, p2 in zip(pa, pb):
-            matrix.append([p1[0], p1[1], 1, 0,
-                           0, 0, -p2[0]*p1[0], -p2[0]*p1[1]])
-            matrix.append([0, 0, 0, p1[0],
-                           p1[1], 1, -p2[1]*p1[0], -p2[1]*p1[1]])
+            matrix.append([p1[0], p1[1], 1, 0, 0, 0, -p2[0] * p1[0], -p2[0] * p1[1]])
+            matrix.append([0, 0, 0, p1[0], p1[1], 1, -p2[1] * p1[0], -p2[1] * p1[1]])
         A = numpy.matrix(matrix, dtype=numpy.float32)
         B = numpy.array(pb).reshape(8)
         res = numpy.dot(numpy.linalg.inv(A.T * A) * A.T, B)
@@ -51,8 +55,8 @@ def perspective(img: IMG, points: List[Tuple[float, float]]):
     img_w, img_h = img.size
     points_w = [p[0] for p in points]
     points_h = [p[1] for p in points]
-    new_w = max(points_w) - min(points_w)
-    new_h = max(points_h) - min(points_h)
+    new_w = int(max(points_w) - min(points_w))
+    new_h = int(max(points_h) - min(points_h))
     p = [(0, 0), (img_w, 0), (img_w, img_h), (0, img_h)]
     coeffs = find_coeffs(points, p)
     return img.transform((new_w, new_h), Image.PERSPECTIVE, coeffs, Image.BICUBIC)
@@ -60,63 +64,74 @@ def perspective(img: IMG, points: List[Tuple[float, float]]):
 
 def save_gif(frames: List[IMG], duration: float) -> BytesIO:
     output = BytesIO()
-    imageio.mimsave(output, frames, format='gif', duration=duration)
+    imageio.mimsave(output, frames, format="gif", duration=duration)
     return output
 
 
 def to_jpg(frame: IMG, bg_color=(255, 255, 255)) -> IMG:
-    if frame.mode == 'RGBA':
-        bg = Image.new('RGB', frame.size, bg_color)
+    if frame.mode == "RGBA":
+        bg = Image.new("RGB", frame.size, bg_color)
         bg.paste(frame, mask=frame.split()[3])
         return bg
     else:
-        return frame.convert('RGB')
+        return frame.convert("RGB")
 
 
 def save_jpg(frame: IMG) -> BytesIO:
     output = BytesIO()
-    frame = frame.convert('RGB')
-    frame.save(output, format='jpeg')
+    frame = frame.convert("RGB")
+    frame.save(output, format="jpeg")
     return output
 
 
 def to_image(data: bytes, convert: bool = True) -> IMG:
     image = Image.open(BytesIO(data))
     if convert:
-        image = square(to_jpg(image).convert('RGBA'))
+        image = square(to_jpg(image).convert("RGBA"))
     return image
 
 
 async def load_image(name: str) -> IMG:
     image = await get_image(name)
-    return Image.open(BytesIO(image)).convert('RGBA')
+    return Image.open(BytesIO(image)).convert("RGBA")
 
 
 async def load_font(name: str, fontsize: int) -> FreeTypeFont:
     font = await get_font(name)
-    return ImageFont.truetype(BytesIO(font), fontsize, encoding='utf-8')
+    return ImageFont.truetype(BytesIO(font), fontsize, encoding="utf-8")
 
 
-async def text_to_pic(text: str, fontsize: int = 30, padding: int = 50,
-                      bg_color=(255, 255, 255), font_color=(0, 0, 0)) -> BytesIO:
+async def text_to_pic(
+    text: str,
+    fontsize: int = 30,
+    padding: int = 50,
+    bg_color=(255, 255, 255),
+    font_color=(0, 0, 0),
+) -> BytesIO:
     font = await load_font(DEFAULT_FONT, fontsize)
     text_w, text_h = font.getsize_multiline(text)
 
-    frame = Image.new('RGB', (text_w + padding * 2,
-                      text_h + padding * 2), bg_color)
+    frame = Image.new("RGB", (text_w + padding * 2, text_h + padding * 2), bg_color)
     draw = ImageDraw.Draw(frame)
     draw.multiline_text((padding, padding), text, font=font, fill=font_color)
     return save_jpg(frame)
 
 
-async def fit_font_size(text: str, max_width: float, max_height: float,
-                        fontname: str, max_fontsize: int, min_fontsize: int,
-                        stroke_ratio: float = 0) -> int:
+async def fit_font_size(
+    text: str,
+    max_width: float,
+    max_height: float,
+    fontname: str,
+    max_fontsize: int,
+    min_fontsize: int,
+    stroke_ratio: float = 0,
+) -> int:
     fontsize = max_fontsize
     while True:
         font = await load_font(fontname, fontsize)
         width, height = font.getsize_multiline(
-            text, stroke_width=int(fontsize * stroke_ratio))
+            text, stroke_width=int(fontsize * stroke_ratio)
+        )
         if width > max_width or height > max_height:
             fontsize -= 1
         else:
